@@ -1,8 +1,8 @@
 from .DefBuilder import DefBuilder
 from .DocModel import DocModel
 from .LatexBuilder import LatexBuilder
-from .TemplateLoader import TemplateLoader
-from .TemplateOptions import TemplateOptions, Tag
-from .TemplateRenderer import TemplateRenderer
 from .PublicTemplateLoader import PublicTemplateLoader
+from .TemplateLoader import TemplateLoader
+from .TemplateOptions import Tag, TemplateOptions
+from .TemplateRenderer import TemplateRenderer
 from .version import __version__
